jacinle.io.fs
=============

.. automodule:: jacinle.io.fs

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      LSDirectoryReturnType
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      as_file_descriptor
      dump
      dump_mat
      dump_npy
      dump_npz
      dump_npz_compressed
      dump_pkl
      dump_pklgz
      dump_pth
      fs_verbose
      link
      load
      load_h5
      load_mat
      load_npy
      load_npz
      load_pkl
      load_pklgz
      load_pth
      load_txt
      locate_newest_file
      lsdir
      mkdir
      open
      open_gz
      open_h5
      open_txt
      remove
      safe_dump
      set_fs_verbose
      tempfile
   
   

   
   
   








.. rubric:: Class LSDirectoryReturnType
.. autoclass:: LSDirectoryReturnType
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: as_file_descriptor

.. autofunction:: dump

.. autofunction:: dump_mat

.. autofunction:: dump_npy

.. autofunction:: dump_npz

.. autofunction:: dump_npz_compressed

.. autofunction:: dump_pkl

.. autofunction:: dump_pklgz

.. autofunction:: dump_pth

.. autofunction:: fs_verbose

.. autofunction:: link

.. autofunction:: load

.. autofunction:: load_h5

.. autofunction:: load_mat

.. autofunction:: load_npy

.. autofunction:: load_npz

.. autofunction:: load_pkl

.. autofunction:: load_pklgz

.. autofunction:: load_pth

.. autofunction:: load_txt

.. autofunction:: locate_newest_file

.. autofunction:: lsdir

.. autofunction:: mkdir

.. autofunction:: open

.. autofunction:: open_gz

.. autofunction:: open_h5

.. autofunction:: open_txt

.. autofunction:: remove

.. autofunction:: safe_dump

.. autofunction:: set_fs_verbose

.. autofunction:: tempfile


